@@ -1,5 +1,6 @@
 from .settings import settings
 from .auth import Auth
+from .app import App
 import requests
 import json
 from github import Github
@@ -117,20 +118,19 @@ class Transfer:
 
         return response.json()
 
-    def GenerateApp(self, gitAccessToken, app, version):
+    def GenerateApp(app = "", gitAccessToken = "", version = ""):
         if not Auth.tokenValid():
             Auth.refreshToken()
 
         # Get app and collection data
-        appData = requests.get(settings.baseURL + 'api/app/' + app + '?extended=true', headers={'Authorization': 'Bearer ' + settings.token})
-        collectionData = appData.json()["data"]
-        collectionData = appData["collections"]
+        responseApp = App(app).ReadOne(extended=True)
+        collectionData = responseApp["collections"]
         collectionData = json.dumps(collectionData)
-        appData = json.dumps(appData)
+        appData = json.dumps(responseApp)
 
-        # Get current version of api used
-        versionData = requests.get(settings.baseURL + 'api/version/', headers={'Authorization': 'Bearer ' + settings.token})
-        versionData = versionData.json()["data"]
+        # Get current version of api, web_application and web_server
+        responseVersion = requests.get(settings.baseURL + 'api/version/', headers={'Authorization': 'Bearer ' + settings.token})
+        versionData = responseVersion.json()["data"]
 
         g = Github(gitAccessToken)
         repo = g.get_repo("bharkema/Clappform_models")
@@ -143,11 +143,11 @@ class Transfer:
         commitMessage = "New App"
         configData = {
             "timestamp": timestamp_int,
-            "created_by": __USERNAME__,
+            "created_by": settings.username,
             "enviroment": settings.baseURL,
-            "api_version": versionData["data"]["api"],
-            "web_application_version": versionData["data"]["web_application"],
-            "web_server_version": versionData["data"]["web_server"],
+            "api_version": versionData["api"],
+            "web_application_version": versionData["web_application"],
+            "web_server_version": versionData["web_server"],
             "deployable": "true"
         }
         appFilePath = "Apps/" + app + "/" + version +"/ "+ timestamp + "_app.json"
